## Summary

Baseprint document successions are preserved in Git-compatible [1] repositories and archives. Three such examples are the Software Heritage Archive, GitHub, and GitLab. See the Relationship to Git section for more details. The data archived is the machine-readable content of a document, separated from how it is visually presented. The benefits of this separation are discussed in the Diversity of Reading Venues section. A key component to making this separation possible is discussed in the Document Succession Identifiers section. These identifiers can be used for bibliographic references similar to a DOI [2]. This extends one of the great features of traditional academic publishing, namely, the ability of researchers to reference a static archived document long into the future.

## Document Succession Identifiers

A Document Succession Identifier (DSI) [3] is an intrinsic persistent identifier [4] of a Baseprint document succession. It is a textual identifier similar to a DOI [2] or a web address URL. This document itself is archived as a Baseprint document succession with DSI:

    dsi:wk1LzCaCSKkIvLAYObAvaoLNGPc

This is a base DSI, which identifies all snapshots within a Baseprint document succession, both current and future. Similar to textbooks and preprints, Baseprint document successions contain multiple editions (or versions) of a Baseprint document, each encoded as a Baseprint document snapshot [5]. A base DSI identifies all the editions of a document added to a Baseprint succession. Usually, readers are interested in the latest edition in the Baseprint succession.

An edition number can follow a base DSI to identify a specific static edition. For instance:

    dsi:wk1LzCaCSKkIvLAYObAvaoLNGPc/1.1

## Conclusion

As of late 2023, Baseprint successions have been implemented and used by the author for over a year. Authors interested in publishing Baseprint successions can visit try.perm.pub to get started.

For technical details on how DSIs are implemented, see the Document Succession Identifier Specification [3] or the software library at gitlab.com/perm.pub/hidos.

## Acknowledgments

This document was copyedited using CopyAid.it, which uses OpenAI GPT-4.

## Changes

### From Edition 1.1 to 2.1

- The “digital succession” terminology has been update to “Baseprint document succession” terminology.